@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2004 Nate Nielsen
+ * Copyright (C) 2004 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,6 @@
 #define SETTING_EXPIRE      AGENT_SETTINGS "/cache_expire"
 #define SETTING_AUTH        AGENT_SETTINGS "/cache_authorize"
 #define SETTING_DISPLAY     AGENT_SETTINGS "/cache_display"
-#define SETTING_AGENT_SSH   AGENT_SETTINGS "/load_ssh"
 #define METHOD_GNOME        "gnome"
 
 /* -----------------------------------------------------------------------------
@@ -51,13 +50,13 @@
 /* Called from the original process before and after fork */
 void seahorse_agent_prefork ();
 void seahorse_agent_postfork (pid_t child);
+void seahorse_agent_childsetup ();
 
 /* Called in the new child process */
 gboolean seahorse_agent_init ();
 void seahorse_agent_uninit ();
 
 /* Global options to set from the command line */
-extern gboolean seahorse_agent_displayvars;
 extern gboolean seahorse_agent_cshell;
 extern gboolean seahorse_agent_execvars;
 extern gboolean seahorse_agent_any_display;
@@ -131,20 +130,4 @@ void seahorse_agent_status_init ();
 void seahorse_agent_status_cleanup ();
 void seahorse_agent_status_update ();
 
-/* -----------------------------------------------------------------------------
- * seahorse-agent-ssh.c
- */
- 
-#define SEAHORSE_SSH_PING_MSG             252
-
-/* Called from the original process before and after fork */
-void     seahorse_agent_ssh_prefork ();
-void     seahorse_agent_ssh_postfork (pid_t child);
-
-gboolean seahorse_agent_ssh_init ();
-GList*   seahorse_agent_ssh_cached_keys ();
-guint    seahorse_agent_ssh_count_keys ();
-void     seahorse_agent_ssh_clearall ();
-void     seahorse_agent_ssh_uninit ();
-
 #endif /* __SEAHORSE_AGENT_H__ */
