@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2005 Nate Nielsen
+ * Copyright (C) 2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,6 +128,7 @@ typedef enum {
 
 /* Forward declaration */
 struct _SeahorseKeySource;
+struct _SeahorseContext;
 
 typedef struct _SeahorseKey SeahorseKey;
 typedef struct _SeahorseKeyClass SeahorseKeyClass;
@@ -145,6 +146,9 @@ struct _SeahorseKey {
     SeahorseKeyEType            etype;
     guint                       flags;
     struct _SeahorseKeySource*  sksrc;
+
+    /*< private >*/
+    struct _SeahorseContext*    attached_to;
     struct _SeahorseKey*        preferred;
 };
 
